#!/bin/bash

echo
echo "DION ROOMS Vision Kiosk installation script"

if [ "$1" = "-h" ] || [ -z "$1" ];then
    echo "$0 [parameters] user"
    echo "$0 -d"
    echo
    echo -e "\tuser - kiosk user name"
    echo -e "\t-d disable kiosk mode"
    echo
    echo "IMPORTANT: run it under sudo/with root permissions"
    exit 0
fi

if [ "$1" = "-d" ];then
    echo "Disabling Kiosk mode"

    cp /etc/X11/fly-dm/fly-dmrc /etc/X11/fly-dm/fly-dmrc.bckp`date +'%Y%m%d%H%M%S'`""
    sed -i 's/AutoLoginEnable=true/AutoLoginEnable=false/' /etc/X11/fly-dm/fly-dmrc
    exit 0
fi

BASEDIR=$(dirname "$0")
START_DION_ROOMS_SCRIPT_NAME=startDionRooms.sh

KIOSK_USERNAME="$1"
KIOSK_FLY_USER_DIR="/etc/fly-kiosk/$KIOSK_USERNAME"
KIOSK_FLY_USER_DESKTOP_DIR="/etc/fly-kiosk/$KIOSK_USERNAME/desktop"
KIOSK_FLY_SINGLE_DIR="/etc/fly-kiosk/$KIOSK_USERNAME/single"
KIOSK_FLY="$KIOSK_FLY_SINGLE_DIR/${START_DION_ROOMS_SCRIPT_NAME}.desktop"
KIOSK_FLY_XKBMAP="$KIOSK_FLY_USER_DIR/fly-xkbmap.desktop"
KIOSK_FLY_SHUTDOWN="$KIOSK_FLY_USER_DIR/desktop/exit.desktop"
KIOSK_FLY_SOUND_APPLET="$KIOSK_FLY_USER_DIR/fly-sound-applet.desktop"

KIOSK_USER_HOME="/home/$KIOSK_USERNAME"
KIOSK_START_SCRIPT="$KIOSK_USER_HOME/$START_DION_ROOMS_SCRIPT_NAME"
KIOSK_USER_CONFIG_DIR="$KIOSK_USER_HOME/.config"
POWER_MANAGEMENT_FILE="$KIOSK_USER_CONFIG_DIR/powermanagementprofilesrc"
CHROMIUM_CONFIG_DIR="$KIOSK_USER_CONFIG_DIR/chromium"
CHROMIUM_CONFIG_FIRST_RUN="$CHROMIUM_CONFIG_DIR/First\ Run"
CHROMIUM_CONFIG_DEFAULT_DIR="$CHROMIUM_CONFIG_DIR/Default"
CHROMIUM_CONFIG_PREF_FILE="$CHROMIUM_CONFIG_DEFAULT_DIR/Preferences"

# (1) create kiosk user in OS
echo "Creating kiosk user $KIOSK_USERNAME"
read -sp "Enter password: " PASSWORD
useradd -m -p $(openssl passwd -1 $PASSWORD) $KIOSK_USERNAME
echo 

# (2) install chromium if missing
RES=`apt list --installed 2>/dev/null| grep "chromium/"`""
if [ "$RES" = "" ];then
    echo "Installing chromium"
    apt-get install -f chromium
else
    echo "Chromium already installed"
    echo "Version: $RES"
fi

# (3) create chromium start script
echo "Creating Dion Rooms Vision start script"
cat > $KIOSK_START_SCRIPT <<EOL
#!/bin/bash
/usr/bin/chromium --noerrdialogs --disable-infobars --check-for-update-interval=31536000 --force-device-scale-factor=2.5 --kiosk https://rooms.dion.vc
EOL
chmod 555 $KIOSK_START_SCRIPT

# (4) enable kiosk mode for kiosk user 
# enabling kiosk script, fly-xkbmap apps runnable for kiosk user
echo "Enabling Kiosk mode for $KIOSK_USERNAME"
mkdir -p $KIOSK_FLY_SINGLE_DIR
mkdir -p $KIOSK_FLY_USER_DESKTOP_DIR
cat > $KIOSK_FLY << EOL
[Desktop Entry]
Name=$START_DION_ROOMS_SCRIPT_NAME
GenericName=$START_DION_ROOMS_SCRIPT_NAME
Type=Application
Exec=$KIOSK_START_SCRIPT
Icon=application-x-executable
EOL

cat > $KIOSK_FLY_XKBMAP << EOL
[Desktop Entry]
Name=Keyboard layout
Type=Application
Comment=Setup Keyboard layout
Exec=fly-xkbmap
Icon=preferences-desktop-keyboard
EOL

cat > $KIOSK_FLY_SOUND_APPLET << EOL
[Desktop Entry]
Name=fly-sound-applet
GenericName=fly-sound-applet
Type=Application
Exec=/usr/bin/fly-sound-applet
Icon=application-x-executable
EOL

cat > $KIOSK_FLY_SHUTDOWN << EOL
[Desktop Entry]
Name=Exit...
Type=Application
Exec=fly-shutdown.sh
Icon=system-log-out
Name[ru]=Завершение работы...
EOL

chown -R root:$KIOSK_USERNAME $KIOSK_FLY_USER_DIR

# (5) auto-login for kiosk user
echo "Enabling auto-login for $KIOSK_USERNAME"
cp /etc/X11/fly-dm/fly-dmrc /etc/X11/fly-dm/fly-dmrc.bckp`date +'%Y%m%d%H%M%S'`""
sed -i 's/AutoLoginEnable=false/AutoLoginEnable=true/' /etc/X11/fly-dm/fly-dmrc
sed -i 's/AutoLoginAgain=false/AutoLoginAgain=true/'   /etc/X11/fly-dm/fly-dmrc
sed -i "s/^AutoLoginUser=\(.*\)$/AutoLoginUser=$KIOSK_USERNAME/" /etc/X11/fly-dm/fly-dmrc


# 
# (6) configuring chromium settings for kiosk user
# enabling microphone & camera for https://dion.vc by default
mkdir -p $CHROMIUM_CONFIG_DEFAULT_DIR
cp $BASEDIR/Preferences $CHROMIUM_CONFIG_DEFAULT_DIR
touch "$CHROMIUM_CONFIG_FIRST_RUN"
chown -R $KIOSK_USERNAME:$KIOSK_USERNAME $CHROMIUM_CONFIG_DIR
sed -i 's/"media_stream_mic":{}/"media_stream_mic":{"https:\/\/dion\.vc:443,\*": {"expiration": "0","last_modified": "13271235276310223","model": 0,"setting": 1}}/' $CHROMIUM_CONFIG_PREF_FILE
sed -i 's/"media_stream_camera":{}/"media_stream_camera":{"https:\/\/dion\.vc:443,\*": {"expiration": "0","last_modified": "13271235276310223","model": 0,"setting": 1}}/' $CHROMIUM_CONFIG_PREF_FILE

# (7) configuring power management for kiosk user
cat > $POWER_MANAGEMENT_FILE << EOL
[AC][DPMSControl]
idleTime=0
[AC][DimDisplay]
idleTime=0
[Battery][DPMSControl]
idleTime=0
[Battery][DimDisplay]
idleTime=0
[Battery][SuspendToRam]
idleTime=0
[LowBattery][DPMSControl]
idleTime=0
[LowBattery][DimDisplay]
idleTime=0
[LowBattery][SuspendToRam]
idleTime=0
EOL



# (8) installing intel driver if intel vga 
INTEL_CARD=`lspci | grep -A 2 -i "VGA" | grep Intel`""
if [ ! -z "$INTEL_CARD" ];then
	# check whether driver is already installed. If not, install it
	RES=`apt list --installed 2>/dev/null| grep "xserver-xorg-video-intel/"`""
	if [ "$RES" = "" ];then
		echo "Installing Intel video card driver i915"
		apt-get install -f xserver-xorg-video-intel mesa-utils
	else
		echo "Intel video card driver already installed"
	fi
	
	# check if module already loaded. if not, load it
	RES=`lsmod | grep "^i915"`""
	if [ "$RES" = "" ];then
		echo "Loading i915 video driver"
		modprobe i915
	else
		echo "i915 video driver is already loaded"
	fi
	
	RES=`grep "i915" /etc/X11/xorg.conf.d/05-intel.conf`""
	if [ "$RES" = "" ];then
		echo "Configuring i915 video driver in xorg"
		cat >> /etc/X11/xorg.conf.d/05-intel.conf << EOL
Section "Device"
	Identifier "Intel Graphics"
	Driver "i915"
	Option "DRI" "3"
	Option "TearFree" "true"
EndSection
EOL
	else
		echo "i915 video driver is already configured in X11"
	fi
	# auto-loading driver i915
	if [ ! -f /etc/modules-load.d/i915.conf ]; then
		echo "Configuring i915 video driver auto-loading"
		echo i915 > /etc/modules-load.d/i915.conf
	fi
fi

# (9) configuring fly theme
FLY_THEME_PATH="$KIOSK_USER_HOME/.fly/theme"
FLY_THEME_FILE="$FLY_THEME_PATH/current.themerc"
if [ ! -f $FLY_THEME_FILE ]; then
	echo "Creating $FLY_THEME_FILE"
	mkdir -p $FLY_THEME_PATH
	cat > $FLY_THEME_FILE << EOL
LockerOnDPMS=false
LockerOnLid=false
LockerOnSleep=false
LockerOnSwitch=false
ScreenSaverDelay=0
EOL

else
	echo "Editing $FLY_THEME_FILE to configure for kiosk mode"
	sed -i 's/LockerOnDPMS=true/LockerOnDPMS=false/' 	$FLY_THEME_FILE
	sed -i 's/LockerOnLid=true/LockerOnLid=false/' 		$FLY_THEME_FILE
	sed -i 's/LockerOnSleep=true/LockerOnSleep=false/' 	$FLY_THEME_FILE
	sed -i 's/LockerOnSwitch=true/LockerOnSwitch=false/' 		$FLY_THEME_FILE
	sed -i "s/^ScreenSaverDelay=\(.*\)$/ScreenSaverDelay=0/" 	$FLY_THEME_FILE
fi

# (1000) changing files owner in $KIOSK_USER_HOME to KIOSK_USERNAME
chown -R $KIOSK_USERNAME:$KIOSK_USERNAME $KIOSK_USER_HOME
